==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/WorkspaceKeyDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.WorkspaceKeyDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Details of the customer managed key associated with the workspace
 * @property keyVaultUrl Workspace Key sub-resource key vault url
 * @property name Workspace Key sub-resource name
 */
public data class WorkspaceKeyDetailsArgs(
    public val keyVaultUrl: Output<String>? = null,
    public val name: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.WorkspaceKeyDetailsArgs> {
    override fun toJava(): com.pulumi.azurenative.synapse.inputs.WorkspaceKeyDetailsArgs =
        com.pulumi.azurenative.synapse.inputs.WorkspaceKeyDetailsArgs.builder()
            .keyVaultUrl(keyVaultUrl?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkspaceKeyDetailsArgs].
 */
@PulumiTagMarker
public class WorkspaceKeyDetailsArgsBuilder internal constructor() {
    private var keyVaultUrl: Output<String>? = null

    private var name: Output<String>? = null

    /**
     * @param value Workspace Key sub-resource key vault url
     */
    @JvmName("kgwgnhdcvnmitsfx")
    public suspend fun keyVaultUrl(`value`: Output<String>) {
        this.keyVaultUrl = value
    }

    /**
     * @param value Workspace Key sub-resource name
     */
    @JvmName("ctboiojkwojetius")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Workspace Key sub-resource key vault url
     */
    @JvmName("tsfygkgxpcbgsssq")
    public suspend fun keyVaultUrl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyVaultUrl = mapped
    }

    /**
     * @param value Workspace Key sub-resource name
     */
    @JvmName("dtnonhcqdhmqgqeh")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): WorkspaceKeyDetailsArgs = WorkspaceKeyDetailsArgs(
        keyVaultUrl = keyVaultUrl,
        name = name,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/WorkspaceKeyDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.WorkspaceKeyDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Details of the customer managed key associated with the workspace
 * @property keyVaultUrl Workspace Key sub-resource key vault url
 * @property name Workspace Key sub-resource name
 */
public data class WorkspaceKeyDetailsArgs(
    public val keyVaultUrl: Output<String>? = null,
    public val name: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.WorkspaceKeyDetailsArgs> {
    override fun toJava(): com.pulumi.azurenative.synapse.inputs.WorkspaceKeyDetailsArgs =
        com.pulumi.azurenative.synapse.inputs.WorkspaceKeyDetailsArgs.builder()
            .keyVaultUrl(keyVaultUrl?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkspaceKeyDetailsArgs].
 */
@PulumiTagMarker
public class WorkspaceKeyDetailsArgsBuilder internal constructor() {
    private var keyVaultUrl: Output<String>? = null

    private var name: Output<String>? = null

    /**
     * @param value Workspace Key sub-resource key vault url
     */
    @JvmName("iyaktfonognqckbd")
    public suspend fun keyVaultUrl(`value`: Output<String>) {
        this.keyVaultUrl = value
    }

    /**
     * @param value Workspace Key sub-resource name
     */
    @JvmName("xwiaiydlwpxfdbog")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Workspace Key sub-resource key vault url
     */
    @JvmName("uddmgimunxoticla")
    public suspend fun keyVaultUrl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyVaultUrl = mapped
    }

    /**
     * @param value Workspace Key sub-resource name
     */
    @JvmName("elrcsrqheheugrlu")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): WorkspaceKeyDetailsArgs = WorkspaceKeyDetailsArgs(
        keyVaultUrl = keyVaultUrl,
        name = name,
    )
}
